CQROptions class

QR Code二维码指令参数

Constructors

CQROptions({int x = 0, int y = 0, int model = 2, int unit = 6, String errorLevel = CQRErrorLevel.l, dynamic mask = CQRMask.auto, String dataMode = CQRDataMode.auto, required dynamic data})

Properties

data → dynamic
数据:自动传字符串,手动传CQRManualSegment数组
final
dataMode String
数据模式 A自动 / M手动
final
errorLevel String
纠错级别 H/Q/M/L,默认L
final
hashCode int
The hash code for this object.
no setterinherited
mask → dynamic
掩码类型 0-7/8/AUTO
final
model int
QR规范版本 1原始 / 2增强,默认2
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unit int
模块单元格大小 1-32,默认6
final
x int
横向起始位置,默认0
final
y int
纵向起始位置,默认0
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited